# google-translate
Small library to translate text for free using Google translate.

See [docs](https://mrs0m30n3.github.io/google-translate/docs/) for more informations.

# INSTALLATION

### Install From Source
1. Download & extract source from [here](https://github.com/MrS0m30n3/google-translate/archive/0.1.zip)
2. Change directory into **google-translate-0.1/**
3. Run `sudo python setup.py install`

### Install From [Pypi](https://pypi.python.org/pypi/doodle-translate/0.1)
1. Run `sudo pip install doodle-translate`

# Usage

```python
import google_translate

translator = google_translate.GoogleTranslator()
print translator.translate("hello world", "french")
```

# AUTHORS
Check the [AUTHORS](https://github.com/MrS0m30n3/google-translate/blob/master/AUTHORS) file

# LICENSE
Unlicense (public domain)
